@@ -30,7 +30,7 @@
 from supybot.test import *
 
 class AdminTestCase(PluginTestCase):
-    plugins = ('Admin',)
+    plugins = ('Admin', 'Utilities')
     def testChannels(self):
         def getAfterJoinMessages():
             m = self.irc.takeMsg()
@@ -95,7 +95,6 @@ class AdminTestCase(PluginTestCase):
         self.assertEqual(m.args[1], 'key')
 
     def testNick(self):
-        original = conf.supybot.nick()
         try:
             m = self.getMsg('nick foobar')
             self.assertEqual(m.command, 'NICK')
@@ -115,20 +114,26 @@ class AdminTestCase(PluginTestCase):
     def testNoJoinOnUnprivilegedInvite(self):
         try:
             world.testing = False
-            self.irc.feedMsg(ircmsgs.invite(conf.supybot.nick(), '#foo', prefix='foo!bar@baz'))
-            self.assertResponse('somecommand',
-                'Error: "somecommand" is not a valid command.')
+            for channel in '#foo', '#foo\u0009':
+                self.irc.feedMsg(ircmsgs.invite(conf.supybot.nick(), channel, prefix='foo!bar@baz'))
+                self.assertResponse('somecommand',
+                    'Error: "somecommand" is not a valid command.')
         finally:
             world.testing = True
 
-    def testNoJoinOnUnprivilegedInvite(self):
-        try:
-            world.testing = False
-            self.irc.feedMsg(ircmsgs.invite(conf.supybot.nick(), '#foo\u0009', prefix='foo!bar@baz'))
-            self.assertResponse('somecommand',
-                'Error: "somecommand" is not a valid command.')
-        finally:
-            world.testing = True
+    def testAcmd(self):
+        self.irc.feedMsg(ircmsgs.join('#foo', prefix=self.prefix))
+        self.irc.feedMsg(ircmsgs.join('#bar', prefix=self.prefix))
+        while self.irc.takeMsg():
+            pass
+        msgs = []
+        msg = self.getMsg('acmd echo hi $channel')
+        while msg:
+            msgs.append(msg)
+            msg = self.irc.takeMsg()
+        self.assertCountEqual(
+            [(msg.command,) + msg.args for msg in msgs],
+            [("PRIVMSG", "#foo", "hi #foo"), ("PRIVMSG", "#bar", "hi #bar")])
 
 # vim:set shiftwidth=4 softtabstop=4 expandtab textwidth=79:
 
