@@ -45,8 +45,23 @@ class Continue(Exception):
     pass # Used below, look in the "do" function nested in doJoin.
 
 class AutoMode(callbacks.Plugin):
-    """This plugin, when configured, allows the bot to automatically set modes
-    on users when they join."""
+    """
+    This plugin, when configured, allows the bot to automatically set modes
+    on users when they join.
+
+    * if ``plugins.automode.op`` is set to ``True``, users with the
+      ``#channel,op`` capability are opped when they join.
+    * if ``plugins.automode.halfop`` is set to ``True``, users with the
+      ``#channel,halfop`` are halfopped when they join.
+    * if ``plugins.automode.voice`` is set to ``True``, users with the
+      ``#channel,voice`` are voiced when they join.
+
+    This plugin also kbans people on ``@channel ban list``
+    (``config plugins.automode.ban``) when they join and if moding users with
+    lower capability is enabled, that is also applied to users with higher
+    capability (``config plugins.automode.fallthrough``).
+
+    """
     def doJoin(self, irc, msg):
         channel = msg.channel
         network = irc.network
