@@ -129,7 +129,7 @@ class FactoidsCallback(httpserver.SupyHTTPServerCallback):
             self.write(httpserver.get_template('factoids/index.html'))
         elif len(parts) == 2:
             channel = utils.web.urlunquote(parts[0])
-            if not irc.isChannel(channel):
+            if not ircutils.isChannel(channel):
                 self.send_response(404)
                 self.send_header('Content-type', 'text/html; charset=utf-8')
                 self.end_headers()
@@ -138,8 +138,7 @@ class FactoidsCallback(httpserver.SupyHTTPServerCallback):
                         {'title': 'Factoids - not a channel',
                          'error': 'This is not a channel'})
                 return
-            if not self._plugin.registryValue('web.channel',
-                                              channel, irc.network):
+            if not self._plugin.registryValue('web.channel', channel):
                 self.send_response(403)
                 self.send_header('Content-type', 'text/html; charset=utf-8')
                 self.end_headers()
@@ -262,8 +261,10 @@ class Factoids(callbacks.Plugin, plugins.ChannelDBHandler):
             s = self.registryValue('learnSeparator', chan, network)
             help = callbacks.getHelp
             if simpleSyntax is None:
+                irc = dynamic.irc
+                network = irc.network if irc else None
                 simpleSyntax = conf.supybot.reply.showSimpleSyntax.getSpecific(
-                    dynamic.irc.network, chan)()
+                    network, chan)()
             if simpleSyntax:
                 help = callbacks.getSyntax
             return help(method,
