@@ -46,8 +46,34 @@ _ = PluginInternationalization('Google')
 from .parser import GoogleHTMLParser
 
 class Google(callbacks.PluginRegexp):
-    """This is a simple plugin to provide access to the Google services we
-    all know and love from our favorite IRC bot."""
+    """
+    This is a simple plugin to provide access to the Google services we
+    all know and love from our favorite IRC bot.
+
+    1. google
+
+       Searches for a string and gives you 3 results from Google search
+       ``!google something``
+
+    2. lucky
+
+       Return the first result (Google's "I'm Feeling Lucky" search)
+       ``!lucky something``
+
+    3. calc
+
+       Does mathematic calculations
+       ``!calc 5+4``
+
+    4. translate
+
+       Translates a string
+       ``!translate en ar test``
+
+    Check: `Supported language codes`_
+
+    .. _Supported language codes: <https://cloud.google.com/translate/v2/using_rest#language-params>`
+    """
     threaded = True
     callBefore = ['Web']
     regexps = ['googleSnarfer']
