@@ -28,7 +28,8 @@
 ###
 
 """
-Various math-related commands.
+This plugin provides a calculator, converter, a list of units
+and other useful math functions.
 """
 
 import supybot
