@@ -314,9 +314,20 @@ class Misc(callbacks.Plugin):
             s = format(_('There is no command %q.'),
                         callbacks.formatCommand(command))
             if command[0].lower() in map(str.lower, plugins):
-                s += (' However, "{0}" is the name of a loaded plugin, and '
-                    'you may be able to find its provided commands '
-                    'using \'list {0}\'.'.format(command[0].title()))
+                if "Plugin" in plugins:
+                    template = _(
+                        " However, '{0}' is the name of a loaded plugin, and "
+                        "you may be able to find its help using "
+                        "'plugin help {0}' and its provided commands using "
+                        "'list {0}'."
+                    )
+                else:
+                    template = _(
+                        " However, '{0}' is the name of a loaded plugin, and "
+                        "you may be able to find its provided commands using "
+                        "'list {0}'."
+                    )
+                s += template.format(command[0].title())
             irc.error(s)
     help = wrap(help, [any('something')])
 
@@ -370,7 +381,10 @@ class Misc(callbacks.Plugin):
         If <nick> is given, it takes the continuation of the last command from
         <nick> instead of the person sending this message.
         """
-        userHostmask = msg.prefix.split('!', 1)[1]
+        if '!' in msg.prefix and '@' in msg.prefix:
+            userHostmask = msg.prefix.split('!', 1)[1]
+        else:
+            userHostmask = msg.nick
         if nick:
             try:
                 (private, L) = irc._mores[nick]
@@ -389,12 +403,31 @@ class Misc(callbacks.Plugin):
                       'to see someone else\'s more.  To do so, call this '
                       'command with that person\'s nick.'), Raise=True)
         number = self.registryValue('mores', msg.channel, irc.network)
+
+        if conf.supybot.protocols.irc.experimentalExtensions() \
+                and 'draft/multiline' in irc.state.capabilities_ack:
+            use_multiline = True
+            multiline_cap_values = ircutils.parseCapabilityKeyValue(
+                irc.state.capabilities_ls['draft/multiline'])
+            if multiline_cap_values.get('max-lines', '').isnumeric():
+                number = min(number, int(multiline_cap_values['max-lines']))
+        else:
+            use_multiline = False
+
         msgs = L[-number:]
         msgs.reverse()
         L[-number:] = []
         if msgs:
-            for msg in msgs:
-                irc.queueMsg(msg)
+            if use_multiline and len(msgs) > 1:
+                # If draft/multiline is available, use it.
+                # TODO: set concat=True. For now we can't, because every
+                # message has "(XX more messages)" at the end, so it would be
+                # unreadable if the messages were concatenated
+                irc.queueMultilineBatches(msgs, target=msgs[0].args[0],
+                        targetNick=msg.nick, concat=False)
+            else:
+                for msg in msgs:
+                    irc.queueMsg(msg)
         else:
             irc.error(_('That\'s all, there is no more.'))
     more = wrap(more, [additional('seenNick')])
