@@ -44,7 +44,15 @@ _ = PluginInternationalization('NickAuth')
 
 @internationalizeDocstring
 class NickAuth(callbacks.Plugin):
-    """Supports authentication based on nicks and network services."""
+    """
+    This plugin allows users to use their network services account to
+    authenticate to the bot.
+
+    They first have to use ``@nickauth nick add <the nick>`` while being
+    identified to the bot and then use ``@auth`` when they want to
+    identify to the bot.
+    """
+
     def __init__(self, irc):
         super(NickAuth, self).__init__(irc)
         self._requests = {}
