@@ -85,7 +85,7 @@ class ChannelDBTestCase(ChannelPluginTestCase):
         self.assertError('seen *')
         self.assertNotError('seen %s' % self.nick)
         m = self.assertNotError('seen %s' % self.nick.upper())
-        self.failUnless(self.nick.upper() in m.args[1])
+        self.assertTrue(self.nick.upper() in m.args[1])
         self.assertRegexp('seen user %s' % self.nick,
                           '^%s was last seen' % self.nick)
         self.assertNotError('config plugins.Seen.minimumNonWildcard 0')
