@@ -43,17 +43,11 @@ def configure(advanced):
 
 
 User = conf.registerPlugin('User')
-# This is where your configuration variables (if any) should go.  For example:
-# conf.registerGlobalValue(User, 'someConfigVariableName',
-#     registry.Boolean(False, """Help for someConfigVariableName."""))
-
-conf.registerGroup(User, 'gpg')
-
-conf.registerGlobalValue(User.gpg, 'enable',
-    registry.Boolean(True, """Determines whether or not users are
-    allowed to use GPG for authentication."""))
-conf.registerGlobalValue(User.gpg, 'TokenTimeout',
-    registry.PositiveInteger(60*10, """Determines the lifetime of a GPG
-    authentication token (in seconds)."""))
-
+conf.registerChannelValue(User, 'listInPrivate',
+    registry.Boolean(True, _("""Determines whether the output of 'user list'
+    will be sent in private. This prevents mass-highlights of people who use
+    their nick as their bot username.""")))
+conf.registerGlobalValue(User, 'customWhoamiError',
+    registry.String("", _("""Determines what message the bot sends
+    when a user isn't identified or recognized.""")))
 # vim:set shiftwidth=4 softtabstop=4 expandtab textwidth=79:
