@@ -31,16 +31,20 @@
 import gc
 import os
 import csv
+import sys
 import time
 import codecs
+import string
 import fnmatch
 import os.path
 import threading
 import collections.abc
 
-from .. import callbacks, conf, dbi, ircdb, ircutils, log, utils, world
+from .. import callbacks, conf, dbi, ircdb, ircutils, i18n, log, utils, world
 from ..commands import *
 
+_ = i18n.PluginInternationalization()
+
 class NoSuitableDatabase(Exception):
     def __init__(self, suitable):
         self.suitable = list(suitable)
@@ -185,6 +189,9 @@ class ChannelUserDictionary(collections.abc.MutableMapping):
 
     def __setitem__(self, key, v):
         (channel, id) = key
+        channel = str(channel)  # channel might be an IrcString,
+                                # which is not internalizable
+        channel = sys.intern(channel)
         if channel not in self.channels:
             self.channels[channel] = self.IdDict()
         self.channels[channel][id] = v
@@ -239,6 +246,7 @@ class ChannelUserDB(ChannelUserDictionary):
                     except ValueError:
                         # We'll skip over this so, say, nicks can be kept here.
                         pass
+                    channel = sys.intern(channel)
                     v = self.deserialize(channel, id, t)
                     self[channel, id] = v
                 except Exception as e:
@@ -319,16 +327,23 @@ class ChannelIdDatabasePlugin(callbacks.Plugin):
         self.db.close()
         self.__parent.die()
 
+    def _typeSubstitutions(self):
+        """Returns a dict with keys Types/Type/types/type, whose values are
+        the plugin name with matching capitalization and plural."""
+        return {
+            'Types': format('%p', self.name()),
+            'Type': self.name(),
+            'types': format('%p', self.name().lower()),
+            'type': self.name().lower(),
+        }
+
     def getCommandHelp(self, name, simpleSyntax=None):
-        help = self.__parent.getCommandHelp(name, simpleSyntax)
-        help = help.replace('$Types', format('%p', self.name()))
-        help = help.replace('$Type', self.name())
-        help = help.replace('$types', format('%p', self.name().lower()))
-        help = help.replace('$type', self.name().lower())
-        return help
+        helpTemplate = string.Template(self.__parent.getCommandHelp(
+            name, simpleSyntax))
+        return helpTemplate.substitute(self._typeSubstitutions())
 
     def noSuchRecord(self, irc, channel, id):
-        irc.error('There is no %s with id #%s in my database for %s.' %
+        irc.error(_('There is no %s with id #%s in my database for %s.') %
                   (self.name(), id, channel))
 
     def checkChangeAllowed(self, irc, msg, channel, user, record):
@@ -367,7 +382,7 @@ class ChannelIdDatabasePlugin(callbacks.Plugin):
         self.addValidator(irc, text)
         if text is not None:
             id = self.db.add(channel, at, user, text)
-            irc.replySuccess('%s #%s added.' % (self.name(), id))
+            irc.replySuccess(_('%s #%s added.') % (self.name(), id))
     add = wrap(add, ['channeldb', 'text'])
 
     def remove(self, irc, msg, args, channel, id):
@@ -389,7 +404,7 @@ class ChannelIdDatabasePlugin(callbacks.Plugin):
 
     def searchSerializeRecord(self, record):
         text = utils.str.ellipsisify(record.text, 50)
-        return format('#%s: %q', record.id, text)
+        return format(_('#%s: %q'), record.id, text)
 
     def search(self, irc, msg, args, channel, optlist, glob):
         """[<channel>] [--{regexp,by} <value>] [<glob>]
@@ -424,19 +439,28 @@ class ChannelIdDatabasePlugin(callbacks.Plugin):
             L.append(self.searchSerializeRecord(record))
         if L:
             L.sort()
-            irc.reply(format('%s found: %L', len(L), L))
+            irc.reply(format(_('%s found: %L'), len(L), L))
         else:
             what = self.name().lower()
-            irc.reply(format('No matching %p were found.', what))
+            irc.reply(format(_('No matching %p were found.'), what))
     search = wrap(search, ['channeldb',
                            getopts({'by': 'otherUser',
                                     'regexp': 'regexpMatcher'}),
                            additional(rest('glob'))])
 
     def showRecord(self, record):
-        name = getUserName(record.by)
-        return format('%s #%s: %q (added by %s at %t)',
-                      self.name(), record.id, record.text, name, record.at)
+        template = string.Template(conf.supybot.replies.databaseRecord())
+        username = getUserName(record.by)
+        nick = username.split('!')[0] # nick==username iff this is a registered user
+        return template.substitute(
+            id=record.id,
+            text=utils.str.quoted(record.text),
+            userid=record.by,
+            username=username,
+            nick=nick,
+            at=utils.str.timestamp(record.at),
+            **self._typeSubstitutions()
+        )
 
     def get(self, irc, msg, args, channel, id):
         """[<channel>] <id>
@@ -479,7 +503,7 @@ class ChannelIdDatabasePlugin(callbacks.Plugin):
         """
         n = self.db.size(channel)
         whats = self.name().lower()
-        irc.reply(format('There %b %n in my database.', n, (n, whats)))
+        irc.reply(format(_('There %b %n in my database.'), n, (n, whats)))
     stats = wrap(stats, ['channeldb'])
 
 
