@@ -36,6 +36,7 @@ import csv
 import math
 
 from . import cdb, utils
+from .utils import minisix
 from .utils.iter import ilen
 
 class Error(Exception):
@@ -141,7 +142,7 @@ class DirMapping(MappingInterface):
     def remove(self, id):
         try:
             os.remove(self._makeFilename(id))
-        except EnvironmentError as e:
+        except EnvironmentError:
             raise NoRecordError(id)
 
 class FlatfileMapping(MappingInterface):
@@ -310,7 +311,7 @@ class CdbMapping(MappingInterface):
         del self.db[str(id)]
 
     def __iter__(self):
-        for (id, s) in self.db.iteritems():
+        for (id, s) in self.db.items():
             if id != 'nextId':
                 yield (int(id), s)
 
@@ -329,7 +330,7 @@ class DB(object):
             self.Record = Record
         if Mapping is not None:
             self.Mapping = Mapping
-        if isinstance(self.Mapping, basestring):
+        if isinstance(self.Mapping, minisix.string_types):
             self.Mapping = Mappings[self.Mapping]
         self.map = self.Mapping(filename)
 
@@ -412,7 +413,7 @@ class Record(object):
             self.defaults[name] = default
             self.converters[name] = converter
         seen = set()
-        for (name, value) in kwargs.iteritems():
+        for (name, value) in kwargs.items():
             assert name in self.fields, 'name must be a record value.'
             seen.add(name)
             setattr(self, name, value)
