@@ -280,7 +280,7 @@ class PluginTestCase(SupyTestCase):
 
     def tearDown(self):
         if self.__class__ in (PluginTestCase, ChannelPluginTestCase):
-            # Necessary because there's a test in here that shouldn\'t run.
+            # Necessary because there's a test in here that shouldn't run.
             return
         for (group, original) in self.originals.items():
             group.setValue(original)
@@ -486,7 +486,7 @@ class ChannelPluginTestCase(PluginTestCase):
         if not forceSetup and \
                 self.__class__ in (PluginTestCase, ChannelPluginTestCase):
             return
-        PluginTestCase.setUp(self)
+        PluginTestCase.setUp(self, nick, forceSetup)
         self.irc.feedMsg(ircmsgs.join(self.channel, prefix=self.prefix))
         m = self.irc.takeMsg()
         self.assertFalse(m is None, 'No message back from joining channel.')
