@@ -182,9 +182,24 @@ class ValuesTestCase(SupyTestCase):
         self.assertTrue(v().match('foo'))
         v.set('')
         self.assertEqual(v(), None)
+
+    def testRegexpSetValue(self):
+        v = registry.Regexp(None, 'help')
+        self.assertRaises(registry.InvalidRegistryValue,
+                          v.setValue, r'foo')
         self.assertRaises(registry.InvalidRegistryValue,
                           v.setValue, re.compile(r'foo'))
 
+    def testRegexpDefaultString(self):
+        v = registry.Regexp('m/foo/', 'help')
+        self.assertEqual(v(), re.compile('foo'))
+
+        v = registry.Regexp('', 'help')
+        self.assertEqual(v(), None)
+
+        v = registry.Regexp(None, 'help')
+        self.assertEqual(v(), None)
+
     def testBackslashesKeys(self):
         conf.supybot.reply.whenAddressedBy.strings.get(':foo').set('=/*')
         filename = conf.supybot.directories.conf.dirize('backslashes1.conf')
